ling2me
=============

.. image:: https://ling2me.com/wp-content/uploads/2022/02/logo.png
   :alt: ling2me.com translate API

A Python module to Translate with `Ling2me.com
<https://ling2me.com>`_,.

How to Install
==============

To install using pip run:

    pip install ling2me

How to use this module
======================

This module can be used to web scraping - Extract HTML content.

See following example:

from scraping_link import ScrapingLinkRequest

from ling2me import Ling2MeRequest

translated_text = Ling2MeRequest.translate(apikey, source_text, from_language, to_language)
print(translated_text)

Customer Support
----------------
Simply reach out to us via `Telegram Group
<https://t.me/+XT_P5S51sDA3ODA0>`_ or or write us an `email
<mailto:info@ling2me.com>`_.

`Sign up for our free plan
<https://app.ling2me.com/register>`_ to get a free API key loaded with 100 free credits. No credit card required!


Licence
=======

This software is licensed under the GNU General Public License (version 3) as published by the Free Software Foundation this licence http://www.gnu.org/licenses/ . If you would want a different licence please contact me, on twitter `@nicolasmarin
<https://twitter.com/@nicolasmarin>`_.
